function u0 = schemesIniCon(IniCon, x, N)
% Selects the initial conditions for the schemes
% ============================================================================
% ____________________________________________________________________________
% 18.311 (Principles of Applied Mathematics). MIT, Spring 2013. R. R. Rosales.
%
% function u0 = schemesIniCon(IniCon)
%
% IniCon =  1 ... Chopped cosine: Even, continuous, with corners.
% IniCon =  2 ... Saw-tooth:      Odd,  with discontinuities.
% IniCon =  3 ... Square wave:    Even, with discontinuities.
% IniCon =  4 ... Smooth, even, initial condition.
% IniCon =  5 ... Smooth, even, initial condition, with a significant
%                    high frequency component.
% IniCon =  6 ... Smooth, odd, initial condition.
% IniCon =  7 ... Smooth, odd, initial condition, with a significant
%                    high frequency component.
%
% ============================================================================
u0  = [];
err = rand(1, N) - 0.5;
%
if IniCon == 1;  u0 = max(0, - cos(x))                      + err/10^4; end
if IniCon == 2;  u0 = (x - pi*(1-sign(pi-x)))/pi            + err/10^5; end
if IniCon == 3;  u0 = sign(x-0.5*pi) - sign(x-1.5*pi) - 1   + err/10^5; end
if IniCon == 4;  u0 =  exp(2*(cos(x)-1))                    + err/10^3; end
if IniCon == 5;  u0 = exp(12*(cos(x)-1))                    + err/10^3; end
if IniCon == 6;  u0 =  exp(2*(sin(x)-1))                    + err/10^3; end
if IniCon == 7;  u0 = exp(12*(sin(x)-1))                    + err/10^3; end
%
if isempty(u0); u0 = schemesIniCon(1, x, N); end
% ============================================================================
% EOF
