% schemesREADME
% ============================================================================
% 18.311 (Principles of Applied Mathematics). MIT, Spring 2013. R. R. Rosales.
% ____________________________________________________________________________
%
% -1- How to use the scripts. Input variables and notation.
% -2- Using the scripts to check stability.
%
% ----------------------------------------------------------------------------
% -1- How to use the scripts. Input variables and notation. ++++++++++++++++++
%
%  Each scripts corresponds to a scheme applied to a particular equation, and
%  goes with a set of problems. For example:
%              scheme01a goes with the problems GBNS01a, vNSA01a, and AENS01a.
%
%  All the schemes use periodic boundary conditions, for 0 < x < 2*pi, and do
%  a 3-D plot of the solution in space-time once the calculation is finished.
%
%  The inputs for each script are as follows:
%  lambda = dt/dx ...... where dt is the time  step and
%                              dx is the space step.                     [#1]
%  nu     = dt/dx^2 .... some scripts require that nu be
%                        prescribed, instead of lambda.                  [#1]
%  parameters .......... any parameters the scheme may involve,
%                        like delta in Friedrich's scheme.               [#1]
%  IniCon .............. a natural number, used to select the
%                        initial data. The choices are listed
%                        in schemesIniCon.                               [#1]
%  Tfinal .............. Solve equation for 0 <= t <= Tfinal.            [#2]
%  Npoint .............. Number of space cells in the integration
%                        domain.       That is: dx = 2*pi/Npoint.
%                        Npoint can be an array, in which case a
%                        calculation is performed for every entry.       [#2]
%
%  The variables should be inputed in the order displayed in the script,
%  but the last n-variables can be skipped. As an example, acceptable
%  calls are:
%             scheme01e(lambda, delta, IniCon, Tfinal, Npoint)
%             scheme01e(lambda, delta, IniCon, Tfinal)
%             scheme01e(lambda, delta, IniCon)
%             scheme01e(lambda, delta)
%             scheme01e(lambda)
%             scheme01e
%  Missing variables of type [#1] above will be then requested via a screen
%  input.  Missing variables of type [#2] will be given the default values.
%  These default values are selected in the first few lines of each script,
%  and can be easily changed.
%
%  The scripts also have internal variables, which can be changed by editing
%  the files:
%  Length .... interval where the calculation is done, set to 2*pi.
%  Freeze .... explained in -2- below. The solution is forced to stay within
%              the constraint: |u| <= Freeze.
%
%  The scripts are WRITTEN SO THAT ADAPTING them to other equations/schemes,
%  or changing the initial conditions, or etc., IS EASY.
%
% ----------------------------------------------------------------------------
% -2- Using the scripts to check stability. ++++++++++++++++++++++++++++++++++
%
% When using the scripts to check numerical stability, what you need to do is
% to find ranges of parameters where the scheme is stable.  These ranges will
% be in terms of relationships between the time step dt and the space step dx
% -- for example: lambda = dt/dx < 1 -- as well as restrictions on parameters
% that the scheme may have in it  [read the notes and problem sets for scheme
% descriptions].
%
% WARNING: even a stable scheme blows up if its parameters are selected not
%          in the stable range. Observing blow up for a few parameter values
%          is not enough. You have to explore a reasonable parameter range to
%          conclude "probable" instability.
%
% WARNING. If instabilities arise: Once the errors grow large, further growth
%          is prevented by scaling the solution, at each time step, down to a
%          maximum fixed size. THIS IS FOR PLOTTING REASONS.
%
%          This size is carried by the variable Freeze,  which in most of the
%          scripts is set at Freeze = 250.  You can change it if you need to.
%
% ============================================================================
% EOF
